@@ -140,13 +140,15 @@ def getLetters(typ='nt', fontname='monospace', dpi=500):
     # for each possible base/aa create temporary plot
     for base in colours.keys():
         f = plt.figure(figsize=(1, 1), dpi=dpi, edgecolor='black')
-        a = f.add_subplot(111)
+        a = f.add_subplot(1, 1, 1)
         a.set_xlim(0, 1)
         a.set_ylim(0, 1)
         fs = getFontSize(f, a, 1)
-        a.text(0.5, 0.02, base, fontsize=fs*0.95, fontdict={'family': 'monospace',
-                                                    'name': fontname},
-               color=colours[base], va='baseline', ha='center')
+        a.text(0.5, 0.02, base, fontsize=fs*0.95,
+               fontdict={'family': 'monospace',
+                         'name': fontname},
+               color=colours[base], va='baseline',
+               ha='center')
         plt.gca().set_axis_off()
         a.margins(0, 0)
         f.subplots_adjust(top=1, bottom=0, right=1, left=0,
@@ -262,7 +264,7 @@ def makeCoveragePlot(coverage, dest, dpi=300, height=3, width=5,
 
     # plain plotting of the coverage
     f = plt.figure(figsize=(width, height), dpi=dpi)
-    a = f.add_subplot('211')
+    a = f.add_subplot(2, 1, 1)
     a.plot(x, y, color=colour)
     a.set_xlabel('Position', fontsize=fontsize)
     a.set_ylabel('Coverage', fontsize=fontsize)
@@ -299,7 +301,9 @@ def sequence_logo(alignment,
                   typ='nt',
                   figfontname='Arial',
                   figdpi=300,
-                  figrowlength=50):
+                  figrowlength=50,
+                  start=0,
+                  end=0):
     '''
     Creates a sequence logo based on an entropy calculation using letters
     Scales the letters according to the information content of the alignment
@@ -325,23 +329,37 @@ def sequence_logo(alignment,
     figrowlength: int
             clength of figure (default: 50)
 
+    start: int
+           start pos to be turned into logo
+
+    end: int
+         end pos to be turned into logo
+
     Returns
     -------
     none
     '''
-    alignment_width = len(alignment[0, :])
+
+    if start == 0 and end == 0:
+        alignment_width = len(alignment[0, :])
+    else:
+        if end == 0:
+            end = len(alignment[0,:])
+        alignment_width = len(alignment[0,start:end])
+
     if alignment_width < figrowlength:
         figrowlength = alignment_width
     nsegs = math.ceil(alignment_width / figrowlength)
     f = plt.figure(figsize=(figrowlength, nsegs*2), dpi=figdpi)
     gs = gridspec.GridSpec(ncols=1, nrows=nsegs)
     getLetters(typ=typ, fontname=figfontname, dpi=figdpi)
-    rstart = 0
+    rstart = start
     rend = rstart + figrowlength
+
     for n in range(nsegs):
 
-        if rend > alignment_width:
-            rend = alignment_width
+        if rend > (alignment_width + start):
+            rend = alignment_width + start
         a = plt.subplot(gs[n])
         a.set_xlim(rstart, rstart+figrowlength)
         if typ == 'nt':
@@ -375,7 +393,7 @@ def sequence_logo(alignment,
         a.axis(limits)
         a.set_xticks([rstart, rend])
         a.set_xticklabels([rstart, rend])
-        
+
         a.spines['right'].set_visible(False)
         a.spines['top'].set_visible(False)
         if n == (nsegs - 1):
@@ -399,7 +417,9 @@ def sequence_bar_logo(alignment,
                       figname,
                       typ='nt',
                       figdpi=300,
-                      figrowlength=50):
+                      figrowlength=50,
+                      start=0,
+                      end=0):
     '''
     Creates a sequence logo based on an entropy calculation using bars
     Scales the bars according to the information content of the alignment
@@ -425,22 +445,35 @@ def sequence_bar_logo(alignment,
     figrowlength: int
             clength of figure (default: 50)
 
+    start: int
+           start pos to be turned into logo
+
+    end: int
+         end pos to be turned into logo
+
     Returns
     -------
     none
     '''
-    alignment_width = len(alignment[0, :])
+
+    if start == 0 and end == 0:
+        alignment_width = len(alignment[0, :])
+    else:
+        if end == 0:
+            end = len(alignment[0,:])
+        alignment_width = len(alignment[0,start:end])
+
     if alignment_width < figrowlength:
         figrowlength = alignment_width
     nsegs = math.ceil(alignment_width / figrowlength)
     f = plt.figure(figsize=(figrowlength/5, nsegs*2), dpi=figdpi)
     gs = gridspec.GridSpec(ncols=1, nrows=nsegs)
-    rstart = 0
+    rstart = start
     rend = rstart + figrowlength
 
     for n in range(nsegs):
-        if rend > alignment_width:
-            rend = alignment_width
+        if rend > (alignment_width + start):
+            rend = alignment_width + start
         axes = f.add_subplot(gs[n])
         axes.set_xlim(rstart-0.5, rend-0.5)
         if typ == 'nt':
@@ -547,18 +580,16 @@ def calc_entropy(count, seq_count, typ):
         entropy_per_base[element] = 0
 
     # correct for small sample sizes
-    sample_size_correction = (1/log(2)) * ((s-1)/(2*seq_count))
+    sample_size_correction = (1/log(s,2)) * ((s-1)/(2*seq_count))
     gap_correction = seq_count
     if count.get("-"):
         seq_count -= count.get("-")
     # correct for gaps, since they lower the information content
     gap_correction = seq_count/gap_correction
-
     entropy = 0
     if seq_count == 0:
         return height_per_base, info_per_base
-
-    # caluclate entropy, from that information, from that height
+    # calculate entropy, from that information, from that height
     for base, quantity in count.items():
         if base != "-":
             frequency = quantity/seq_count
@@ -566,11 +597,12 @@ def calc_entropy(count, seq_count, typ):
             entropy -= frequency*log(frequency, 2)
             info_per_base[base] = max_entropy + frequency*log(frequency, 2)
             entropy_per_base[base] = -frequency * log(frequency, 2)
-    information_per_column = max_entropy-entropy-sample_size_correction
+    information_per_column = max_entropy - entropy - sample_size_correction
 
     # if the information content is constant throughout the column,
     # these value will be negative. Since this does not add any information
     # set them to 0
+    # they can be negative due to the sample size correction (otherwise they'd be 0)
     for base, quantity in info_per_base.items():
         if freq_per_base[base]*information_per_column < 0:
             height_per_base[base] = 0
